@@ -164,73 +164,77 @@ forceNetwork <- function(Links,
                          opacityNoHover = 0,
                          clickAction = NULL)
 {
-        # Check if data is zero indexed
-        check_zero(Links[, Source], Links[, Target])
-  
-        # Hack for UI consistency. Think of improving.
-        colourScale <- as.character(colourScale)
-        linkWidth <- as.character(linkWidth)
-        radiusCalculation <- as.character(radiusCalculation)
+    # Check if data is zero indexed
+    check_zero(Links[, Source], Links[, Target])
 
-        # Subset data frames for network graph
-        if (!is.data.frame(Links)) {
-                stop("Links must be a data frame class object.")
-        }
-        if (!is.data.frame(Nodes)) {
-                stop("Nodes must be a data frame class object.")
-        }
-        if (missing(Value)) {
-                LinksDF <- data.frame(Links[, Source], Links[, Target])
-                names(LinksDF) <- c("source", "target")
-        }
-        else if (!missing(Value)) {
-                LinksDF <- data.frame(Links[, Source], Links[, Target], Links[, Value])
-                names(LinksDF) <- c("source", "target", "value")
-        }
-        if (!missing(Nodesize)){
-                NodesDF <- data.frame(Nodes[, NodeID], Nodes[, Group], Nodes[, Nodesize])
-                names(NodesDF) <- c("name", "group", "nodesize")
-                nodesize = TRUE
-        } else {
-                NodesDF <- data.frame(Nodes[, NodeID], Nodes[, Group])
-                names(NodesDF) <- c("name", "group")
-                nodesize = FALSE
-        }
-        
-        LinksDF <- data.frame(LinksDF, colour = linkColour)
-        LinksDF$colour = as.character(LinksDF$colour)
+    # If tbl_df convert to plain data.frame
+    Links <- tbl_df_strip(Links)
+    Nodes <- tbl_df_strip(Nodes)
 
-        # create options
-        options = list(
-                NodeID = NodeID,
-                Group = Group,
-                colourScale = colourScale,
-                fontSize = fontSize,
-                fontFamily = fontFamily,
-                clickTextSize = fontSize * 2.5,
-                linkDistance = linkDistance,
-                linkWidth = linkWidth,
-                charge = charge,
-                # linkColour = linkColour,
-                opacity = opacity,
-                zoom = zoom,
-                legend = legend,
-                nodesize = nodesize,
-                radiusCalculation = radiusCalculation,
-                bounded = bounded,
-                opacityNoHover = opacityNoHover,
-                clickAction = clickAction
-        )
+    # Hack for UI consistency. Think of improving.
+    colourScale <- as.character(colourScale)
+    linkWidth <- as.character(linkWidth)
+    radiusCalculation <- as.character(radiusCalculation)
 
-        # create widget
-        htmlwidgets::createWidget(
-                name = "forceNetwork",
-                x = list(links = LinksDF, nodes = NodesDF, options = options),
-                width = width,
-                height = height,
-                htmlwidgets::sizingPolicy(padding = 10, browser.fill = TRUE),
-                package = "networkD3"
-        )
+    # Subset data frames for network graph
+    if (!is.data.frame(Links)) {
+            stop("Links must be a data frame class object.")
+    }
+    if (!is.data.frame(Nodes)) {
+            stop("Nodes must be a data frame class object.")
+    }
+    if (missing(Value)) {
+            LinksDF <- data.frame(Links[, Source], Links[, Target])
+            names(LinksDF) <- c("source", "target")
+    }
+    else if (!missing(Value)) {
+            LinksDF <- data.frame(Links[, Source], Links[, Target], Links[, Value])
+            names(LinksDF) <- c("source", "target", "value")
+    }
+    if (!missing(Nodesize)){
+            NodesDF <- data.frame(Nodes[, NodeID], Nodes[, Group], Nodes[, Nodesize])
+            names(NodesDF) <- c("name", "group", "nodesize")
+            nodesize = TRUE
+    } else {
+            NodesDF <- data.frame(Nodes[, NodeID], Nodes[, Group])
+            names(NodesDF) <- c("name", "group")
+            nodesize = FALSE
+    }
+
+    LinksDF <- data.frame(LinksDF, colour = linkColour)
+    LinksDF$colour = as.character(LinksDF$colour)
+
+    # create options
+    options = list(
+            NodeID = NodeID,
+            Group = Group,
+            colourScale = colourScale,
+            fontSize = fontSize,
+            fontFamily = fontFamily,
+            clickTextSize = fontSize * 2.5,
+            linkDistance = linkDistance,
+            linkWidth = linkWidth,
+            charge = charge,
+            # linkColour = linkColour,
+            opacity = opacity,
+            zoom = zoom,
+            legend = legend,
+            nodesize = nodesize,
+            radiusCalculation = radiusCalculation,
+            bounded = bounded,
+            opacityNoHover = opacityNoHover,
+            clickAction = clickAction
+    )
+
+    # create widget
+    htmlwidgets::createWidget(
+            name = "forceNetwork",
+            x = list(links = LinksDF, nodes = NodesDF, options = options),
+            width = width,
+            height = height,
+            htmlwidgets::sizingPolicy(padding = 10, browser.fill = TRUE),
+            package = "networkD3"
+    )
 }
 
 #' @rdname networkD3-shiny
