@@ -39,7 +39,12 @@ HTMLWidgets.widget({
     // JSON array with the d3Tree root data
 
     var s = d3.select(el).selectAll("svg");
-
+    
+    // when re-rendering the svg, the viewBox attribute set in the code below, will
+    // be affected by the previously set viewBox. This line ensures, that the 
+    // viewBox will always be calculated right. 
+    s.attr("viewBox", null);
+    
     // margin handling
     //   set our default margin to be 20
     //   will override with x.options.margin if provided
@@ -60,8 +65,9 @@ HTMLWidgets.widget({
       s.node().getBoundingClientRect().height - margin.top - margin.bottom
     );
 
+    //added Math.max(1, ...) to avoid NaN values when dealing with nodes of depth 0.
     tree.size([360, diameter/2])
-        .separation(function(a, b) { return (a.parent == b.parent ? 1 : 2) / a.depth; });
+        .separation(function(a, b) { return (a.parent == b.parent ? 1 : 2) / Math.max(1, a.depth); });
 
     // select the svg group element and remove existing children
     s.attr("pointer-events", "all").selectAll("*").remove();
